Learn R Programming

bdrc (version 2.0.1)

autoplot.tournament: Autoplot method for discharge rating curve tournament

Description

Compare the four discharge rating curves from the tournament object in different ways

Usage

# S3 method for tournament
autoplot(object, type = "boxplot", ...)

Value

Returns an object of class "ggplot2".

Arguments

object

An object of class "tournament"

type

A character denoting what type of plot should be drawn. Possible types are

...

Not used in this function

boxplot

Creates a boxplot of the posterior log-likelihood values transformed to the deviance scale.

See Also

tournament to run a discharge rating curve tournament and summary.tournament for summaries.

Examples

Run this code
# \donttest{
library(ggplot2)
data(krokfors)
set.seed(1)
t_obj <- tournament(formula = Q ~ W, data = krokfors, num_cores = 2)
autoplot(t_obj)
# }

Run the code above in your browser using DataLab