powered by
Compare the four discharge rating curves from the tournament object in different ways
# S3 method for tournament autoplot(object, type = "boxplot", ...)
Returns an object of class "ggplot2".
An object of class "tournament"
A character denoting what type of plot should be drawn. Possible types are
Not used in this function
boxplot
Creates a boxplot of the posterior log-likelihood values transformed to the deviance scale.
tournament to run a discharge rating curve tournament and summary.tournament for summaries.
tournament
summary.tournament
# \donttest{ library(ggplot2) data(krokfors) set.seed(1) t_obj <- tournament(formula = Q ~ W, data = krokfors, num_cores = 2) autoplot(t_obj) # }
Run the code above in your browser using DataLab