powered by
Compare the four discharge rating curves from the tournament object in different ways
# S3 method for tournament autoplot(object, ..., type = "deviance")
returns an object of class "ggplot2".
an object of class "tournament"
other plotting parameters (not used in this function)
a character denoting what type of plot should be drawn. Possible types are
"deviance" to plot the deviance of the four models.
tournament to run a discharge rating curve tournament and summary.tournament for summaries.
tournament
summary.tournament
# \donttest{ library(ggplot2) data(krokfors) set.seed(1) t_obj <- tournament(formula=Q~W,data=krokfors,num_cores=2) autoplot(t_obj) # }
Run the code above in your browser using DataLab